@@ -150,7 +150,7 @@ namespace apg {
             }
         }
 
-        std::vector<std::string> pseudoBangBang(pattern pat, std::vector<bitworld> *clvec) {
+        std::vector<std::string> pseudoBangBang(pattern pat, std::vector<bitworld> *clvec, bool recurse) {
             /*
             * Borrowed from apgmera, and upgraded.
             */
@@ -260,6 +260,17 @@ namespace apg {
                             components.push_back(tx[j]);
                         }
                         // std::cerr << "done!" << std::endl;
+                    } else if (recurse) {
+                        auto cmap = census(ppart, ppart.ascertain_period(), 0, false);
+                        if (cmap.size() == 0) {
+                            std::cerr << "Warning: " << ppart.apgcode() << " gave empty census." << std::endl;
+                            components.push_back(ppart.apgcode());
+                        }
+                        for (auto it = cmap.begin(); it != cmap.end(); ++it) {
+                            for (int i = 0; i < it->second; i++) {
+                                components.push_back(it->first);
+                            }
+                        }
                     } else {
                         components.push_back(ppart.apgcode());
                     }
@@ -385,7 +396,7 @@ namespace apg {
                 lrem -= cluster;
                 if (rigorous) {
                     pattern ppart(lab, lab->demorton(cluster, 1), rule);
-                    pseudoBangBang(ppart, &clusters);
+                    pseudoBangBang(ppart, &clusters, false);
                 } else {
                     clusters.push_back(cluster);
                 }
@@ -421,9 +432,6 @@ namespace apg {
             }
 
             repr = cl2.apgcode();
-            if (bb != 0) {
-                bitcache.emplace(bb, repr);
-            }
             auto it = decompositions.find(repr);
             if (it != decompositions.end()) {
                 elements = it->second;
@@ -437,7 +445,7 @@ namespace apg {
                         // back on pbb if this fails:
                         elements = sss(cl2);
                     }
-                    if (elements.size() == 0) { elements = pseudoBangBang(cl2, 0); }
+                    if (elements.size() == 0) { elements = pseudoBangBang(cl2, 0, recurse); }
                 } else if (recurse && (!b0)) {
                     // We may have a constellation since we've bypassed PseudoBangBang.
                     // This tends to be problematic in B0 and Generations rules with
@@ -457,6 +465,10 @@ namespace apg {
                 }
                 decompositions[repr] = elements;
             }
+
+            if (bb != 0) {
+                bitcache.emplace(bb, repr);
+            }
             
             return std::pair<bool, std::vector<std::string> >(true, elements);
         }
