@@ -205,6 +205,11 @@ extern "C"
         return new(std::nothrow) apg::pattern(ppat->match(*ppat1));
     }
 
+    void* CopyPattern(void* pat) {
+        auto ppat = reinterpret_cast<apg::pattern*>(pat);
+        return new(std::nothrow) apg::pattern(*ppat);
+    }
+
     void* MatchLiveAndDead(void* pat, void* pat1, void* pat0) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         auto ppat1 = reinterpret_cast<apg::pattern*>(pat1);
