@@ -198,13 +198,16 @@ namespace apg {
 
         void write_rle(std::ostream &outstream, hypernode<I> hnode, std::string rule) {
 
+            outstream << "#CLL state-numbering golly" << std::endl;
+
             if (hnode.index == 0) {
 
                 outstream << "x = 1, y = 1, rule = " << gollyrule(rule) << std::endl;
-                outstream << state2string(0) << "!" << std::endl;
+                outstream << "b!" << std::endl;
 
             } else {
 
+                RuleMapper* grm = getMapper(rule);
                 int linelength = 0;
 
                 std::map<std::pair<uint64_t, uint64_t>, uint64_t> cells;
@@ -234,7 +237,7 @@ namespace apg {
                 for (auto it = cells.begin(); it != cells.end(); ++it) {
                     uint64_t y = it->first.first - miny;
                     uint64_t x = it->first.second - minx;
-                    uint64_t c = it->second;
+                    uint64_t c = grm->ll_to_golly(it->second);
 
                     if ((y > lasty) || (x > lastx) || (c != lastc)) {
                         printrun(outstream, runlength, state2string(lastc), linelength);
@@ -255,6 +258,8 @@ namespace apg {
 
                 printrun(outstream, runlength, state2string(lastc), linelength);
                 outstream << "!" << std::endl;
+
+                delete grm;
             }
         }
 
