@@ -527,22 +527,27 @@ namespace apg {
             return dt;
         }
 
-        bool isHexagonal() {
+        std::string rule_symmetries() {
 
             std::string rule = rulestring;
-            if (rule.length() == 0) { return false; }
+            if (rule.length() == 0) { return "NONE"; }
 
             // Remove history suffix:
             if ((rule.length() >= 8) && (rule.substr(rule.length() - 6) == "istory")) {
                 rule = rule.substr(0, rule.length() - 7);
             }
 
-            // Match uppercase 'H' and lowercase 'h':
-            return (((int) rule[rule.length() - 1]) & 31) == 8;
+            std::string syms = get_syms(rule);
 
+            // Match uppercase 'H' and lowercase 'h':
+            if (syms == "99") {
+                syms = ((((int) rule[rule.length() - 1]) & 31) == 8) ? "HEXAGONAL" : "SQUARE";
+            }
+
+            return syms;
         }
 
-        std::string phase_wechsler() {
+        std::string phase_wechsler(std::string syms) {
             /*
             * Returns the extended Wechsler format for the current phase:
             */
@@ -560,12 +565,16 @@ namespace apg {
                     // Remove redundant '_0' suffices:
                     bwv.pop_back();
                 }
-                if (isHexagonal()) {
+
+                if (syms == "HEXAGONAL") {
                     std::string s = wechslerhex(bwv);
                     return ((s.length() > 1280) ? "#" : s);
-                } else {
+                } else if (syms == "SQUARE") {
                     std::string s = wechslerise(bwv, bbox);
                     return ((s.length() > 1280) ? "#" : s);
+                } else {
+                    std::string s = wechslernone(bwv, bbox);
+                    return ((s.length() > 1280) ? "#" : s);
                 }
             } else {
                 return "0";
@@ -583,10 +592,12 @@ namespace apg {
             uint64_t p = ascertain_period();
             basepattern<I> x = advance(0);
 
+            std::string syms = rule_symmetries();
+
             for (uint64_t t = 0; t < p; t++) {
                 if (t != 0) { x = x.advance((rulestring[1] == '0') ? 2 : 1); }
                 // rep = comprep(rep, x.flatlayer(0).wechsler());
-                rep = comprep(rep, x.phase_wechsler());
+                rep = comprep(rep, x.phase_wechsler(syms));
             }
 
             std::ostringstream ss;
